###################################################################
#
# configLetter.tcl - ndert die Default-Paper-Einstellungen
# fr pdftex, dvips und dvipdfm in Letter-Format
#
# Vers.: 1.0   ThF, 4/05
#
###################################################################

##### Packages #####

package require registry 1.0

##### Graphics... #####

wm title . "configLetter";

frame .protwin
pack .protwin -side top -expand true -fill both

text .protwin.protocol -relief sunken -width 50 -height 15 \
    -wrap word -yscrollcommand ".protwin.scrolly set"

scrollbar .protwin.scrolly -command ".protwin.protocol yview" \
        -orient vertical -width 12

button .ende -text "Close" \
    -command {_finishProgram $updb $SHH}

pack .protwin.protocol -side left  -expand true -fill both
pack .protwin.scrolly -side right  -fill y -before .protwin.protocol
pack .ende -side bottom -anchor se -before .protwin -pady 3

##### Procedures... #####

proc _setMessage {msg} {

.protwin.protocol insert end "$msg";

}; # end _setMessage


proc _getRegKey {keypath subkey} {

set key "NULL"

catch {set key [registry get $keypath $subkey]}

return $key

}; # end _getRegKey

proc _changePageSize {rd lrd tail driver} {

set retcode 0;
set retmsg "Failed!!";

set configfile [open "$rd$tail" r]
set configdata [read $configfile]
close $configfile

switch $driver {

    "pdftex" { set retcode [regsub "page_height 297 true mm\npage_width 210 true mm" $configdata \
                "page_height 11 true in\npage_width 8.5 true in\n%page_height 297 true mm\n%page_width 210 true mm" \
                configdata] }

    "dvips" { set retcode [regsub "\n@ A4size" $configdata \
                "\n@ letterSize 8.5in 11in\n\n@ A4size" \
                configdata] }

    "dvipdfm" { set retcode [regsub "\np a4" $configdata \
                "\np letter\n%p a4" \
                configdata] }

    "dvipdfmx" { set retcode [regsub "\np a4" $configdata \
                "\np letter\n%p a4" \
                configdata] }

}; # end switch

if { $retcode == 1 } {

    set retmsg "Done"
    set configfile [open "$lrd$tail" w]
    puts -nonewline $configfile $configdata
    close $configfile

}

return $retmsg;

}; # end _changePageSize


proc _finishProgram {execprog finishcode} {

if {$finishcode == 1} {

    _setMessage "Updating MiKTeX's filename database (this may take a while) ..."
    update idletasks
    eval exec $execprog
    _setMessage "\tDone\n"

}

exit

}; # end _finishProgram

##### The Main Program... #####

set SHH 0;
set MIKREGKEY "HKEY_LOCAL_MACHINE\\SOFTWARE\\MiK\\MiKTeX\\CurrentVersion\\MiKTeX"
set MIKROOT "Install Root"
set MIKLOCALROOT "Local Root"
set PDFTEXTAIL "\\pdftex\\config\\pdftex.cfg";
set DVIPSTAIL "\\dvips\\config\\config.ps";
set DVIPDFMTAIL "\\dvipdfm\\config\\config";
set DVIPDFMXTAIL "\\dvipdfm\\config\\dvipdfmx.cfg";
set UPDBTAIL "\\miktex\\bin\\initexmf --update-fndb"

set ROOTDIR [_getRegKey $MIKREGKEY $MIKROOT];
set LOCALROOTDIR [_getRegKey $MIKREGKEY $MIKLOCALROOT];
set updb $ROOTDIR$UPDBTAIL
regsub -all "\\\\" $updb "/" updb

if {[string compare $ROOTDIR "NULL"] != 0} {

    _setMessage "Installation Folder: $ROOTDIR \n";

    if {[string compare $LOCALROOTDIR "NULL"] != 0} {

        set SHH 1;
        _setMessage "Local TEXMF Tree: $LOCALROOTDIR \n";
        _setMessage "\n"
        _setMessage "Setting letter paper size for:\n"
        _setMessage "\tpdfTeX: [_changePageSize $ROOTDIR $LOCALROOTDIR $PDFTEXTAIL "pdftex"]\n"
        _setMessage "\tDvips: [_changePageSize $ROOTDIR $LOCALROOTDIR $DVIPSTAIL "dvips"]\n"
        _setMessage "\tDvipdfm: [_changePageSize $ROOTDIR $LOCALROOTDIR $DVIPDFMTAIL "dvipdfm"]\n"
        _setMessage "\tDvipdfmx: [_changePageSize $ROOTDIR $LOCALROOTDIR $DVIPDFMXTAIL "dvipdfmx"]\n"
        _setMessage "\n"

    } else {

        _setMessage "No \"Local TEXMF Tree\" found -- Bye...\n";

    }

} else {

     _setMessage "No Installation Folder found -- Bye...\n";

}

### ende von configLetter.tcl
